@@ -29,6 +29,7 @@ import os
 from PyQt4 import QtSql
 
 from freeseer import __version__
+from freeseer import SCHEMA_VERSION
 from freeseer.framework.presentation import Presentation
 from freeseer.framework.failure import Failure, Report
 from freeseer.framework.rss_parser import FeedParser
@@ -39,64 +40,54 @@ class QtDBConnector():
     presentationsModel = None
     failuresModel = None
     recentconnModel = None
-    
+
     def __init__(self, configdir, talkdb_file="presentations.db"):
         """
         Initialize the QtDBConnector
         """
         self.configdir = configdir
         self.talkdb_file = os.path.abspath("%s/%s" % (self.configdir, talkdb_file))
-        
+
         if not os.path.isfile(self.talkdb_file):
             file = open(self.talkdb_file, 'w')
             file.write('')
             file.close()
-        
+
         self.__open_table()
-    
+
     def __open_table(self):
         """
         This function options a connection to the database. Used by the init function.
         """
         self.talkdb = QtSql.QSqlDatabase.addDatabase("QSQLITE")
         self.talkdb.setDatabaseName(self.talkdb_file)
-        
+
         if (self.talkdb.open()):
-            
+
             # check if presentations table exists and if not create it.
             if not self.talkdb.tables().contains("presentations"):
                 self.__create_presentations_table()
                 self.__insert_default_talk()
-            
+
             # check if failures table exists and if not create it.
             if not self.talkdb.tables().contains("failures"):
                 self.__create_failures_table()
-                
+
             # check if recentConnections table exists and if not create it.
             if not self.talkdb.tables().contains("recentconn"):
                 self.__create_recentconn_table()
-                
+
             #verify that correct version of database exists
             self.__update_version()
         else:
             log.error("Unable to create talkdb file.")
-            
+
     def __close_table(self):
         """
-        This function is used to close the connection the the database.    
+        This function is used to close the connection the the database.
         """
         self.talkdb.close()
 
-    def get_program_version_int(self):
-        """
-        Get Freeseer's current version as an integer.
-        """
-        result = []
-        for c in __version__:
-            if c.isdigit():
-                result.append(c)
-        return int(''.join(result))
-    
     def __get_db_version_int(self):
         """
         Get the database's current version. Default is 0 if unset (for 2x and older)
@@ -106,39 +97,41 @@ class QtDBConnector():
         return query.value(0).toInt()[0]
 
     def __update_version(self):
-        """
-        Upgrade database to the latest version.
-        updaterVersion[i] version number of the incremental update function located at updaters[i]
-        updaters[] functions are then called in order starting at the old version to the end.
-        Version # of 2.x and older is 0
-        """
-        
+        """Upgrade database to the latest SCHEMA_VERSION"""
+
         db_version = self.__get_db_version_int()
-        program_version = self.get_program_version_int()
-        if program_version == db_version:
+        if db_version == SCHEMA_VERSION:
             return
-        
+
+        #
+        # Define functions for upgrading between schema versions
+        #
         def update_2xto30():
+            """Incremental update of database from Freeseer 2.x and older to 3.0
+
+            SCHEMA_VERSION is 300
             """
-            Incremental update of database from 2.x and older to 3.0.
-            """
-            QtSql.QSqlQuery('ALTER TABLE presentations RENAME TO presentations_old') #temporary table
+            if db_version > 300:
+                log.debug('Database newer than schema version 300.')
+                return  # No update needed
+
+            log.debug('Updating to schema 300.')
+            QtSql.QSqlQuery('ALTER TABLE presentations RENAME TO presentations_old')  # temporary table
             self.__create_presentations_table()
-            QtSql.QSqlQuery("""INSERT INTO presentations 
+            QtSql.QSqlQuery("""INSERT INTO presentations
                             SELECT Id, Title, Speaker, Description, Level, Event, Room, Time from presentations_old""")
             QtSql.QSqlQuery('DROP TABLE presentations_old')
-        
+
+        #
+        # Perform the upgrade
+        #
         updaters = [update_2xto30]
-        updaterVersion = [0] #next entry is 300
-        
-        if len(updaters) != len(updaterVersion) or db_version not in updaterVersion: #not setup properly
-            log.info('Database upgrade failed.')
-            return
-        for updater in updaters[updaterVersion.index(db_version):]:
+        for updater in updaters:
             updater()
-        QtSql.QSqlQuery('PRAGMA user_version = %i' % program_version)
-        log.info('Upgraded presentations database from version %i', db_version)
-    
+
+        QtSql.QSqlQuery('PRAGMA user_version = %i' % SCHEMA_VERSION)
+        log.info('Upgraded presentations database from version {} to {}'.format(db_version, SCHEMA_VERSION))
+
     def __create_presentations_table(self):
         """
         Creates the presentations table in the database. Should be used to
@@ -154,7 +147,7 @@ class QtDBConnector():
                                         Room varchar(25),
                                         Time timestamp,
                                         UNIQUE (Speaker, Title) ON CONFLICT IGNORE)''')
-        
+
     def __insert_default_talk(self):
         """
         Insert the default talk data into the database.
@@ -167,42 +160,42 @@ class QtDBConnector():
                                     "T105",
                                     "")
         self.insert_presentation(presentation)
-        
+
     def get_talks(self):
         """
         Gets all the talks from the database including all columns.
         """
         result = QtSql.QSqlQuery('''SELECT * FROM presentations''')
         return result
-    
+
     def get_events(self):
         """
         Gets all the talk events from the database.
         """
         result = QtSql.QSqlQuery('''SELECT DISTINCT Event FROM presentations''')
         return result
-    
+
     def get_talk_ids(self):
         """
         Gets all the talk events from the database.
         """
         result = QtSql.QSqlQuery('''SELECT Id FROM presentations''')
         return result
-    
+
     def get_talks_by_event(self, event):
         """
         Gets the talks signed in a specific event from the database.
         """
         result = QtSql.QSqlQuery('''SELECT * FROM presentations WHERE Event=%s''' % event)
         return result
-    
+
     def get_talks_by_room(self, room):
         """
         Gets the talks hosted in a specific room from the database.
         """
         result = QtSql.QSqlQuery('''SELECT * FROM presentations WHERE Room=%s''' % room)
         return result
-    
+
     def get_presentation(self, talk_id):
         """
         Return a Presentation object associated to a talk_id.
@@ -218,19 +211,19 @@ class QtDBConnector():
                              unicode(result.value(7).toString()))    # time
         else:
             p = None
-            
+
         return p
-    
+
     def presentation_exists(self, presentation):
         """
         Check if there's a presentation with the same Speaker and Title already stored
         """
         result = QtSql.QSqlQuery('''SELECT * FROM presentations''')
-        while(result.next()):                    
+        while(result.next()):
             if(unicode(presentation.title) == unicode(result.value(1).toString()) and unicode(presentation.speaker) == unicode(result.value(2).toString())):
-                return True            
+                return True
         return False
-        
+
     #
     # Presentation Create, Update, Delete
     #
@@ -247,7 +240,7 @@ class QtDBConnector():
                                      presentation.room,
                                      presentation.time))
         log.info("Talk added: %s - %s" % (presentation.speaker, presentation.title))
-        
+
     def update_presentation(self, talk_id, presentation):
         """
         Update an existing Presentation in the database.
@@ -260,23 +253,23 @@ class QtDBConnector():
                              presentation.time,
                              talk_id))
         log.info("Talk %s updated: %s - %s" % (talk_id, presentation.speaker, presentation.title))
-        
+
     def delete_presentation(self, talk_id):
         """
         Removes a Presentation from the database
         """
         query = QtSql.QSqlQuery('''DELETE FROM presentations WHERE Id="%s"''' % talk_id)
         log.info("Talk %s deleted." % talk_id)
-        
+
     def clear_database(self):
         """
         Clears the presentations table
         """
         query = QtSql.QSqlQuery('''DELETE FROM presentations''')
         log.info("Database cleared.")
-    
+
     #
-    # Data Model Retrieval 
+    # Data Model Retrieval
     #
     def get_presentations_model(self):
         """
@@ -288,7 +281,7 @@ class QtDBConnector():
             self.presentationsModel.setTable("presentations")
             self.presentationsModel.setEditStrategy(QtSql.QSqlTableModel.OnFieldChange)
             self.presentationsModel.select()
-        
+
         return self.presentationsModel
 
     def get_events_model(self):
@@ -298,9 +291,9 @@ class QtDBConnector():
         """
         self.eventsModel = QtSql.QSqlQueryModel()
         self.eventsModel.setQuery("SELECT DISTINCT Event FROM presentations ORDER BY Event ASC")
-            
+
         return self.eventsModel
-    
+
     def get_dates_from_event_room_model(self, event, room):
         """
         Gets the Rooms Model.
@@ -308,9 +301,9 @@ class QtDBConnector():
         """
         self.datesModel = QtSql.QSqlQueryModel()
         self.datesModel.setQuery("SELECT DISTINCT date(Time) FROM presentations WHERE Event='%s' and Room='%s' ORDER BY Time ASC" % (event, room))
-        
+
         return self.datesModel
-    
+
     def get_rooms_model(self, event):
         """
         Gets the Rooms Model.
@@ -318,15 +311,15 @@ class QtDBConnector():
         """
         self.roomsModel = QtSql.QSqlQueryModel()
         self.roomsModel.setQuery("SELECT DISTINCT Room FROM presentations WHERE Event='%s' ORDER BY Room ASC" % event)
-            
+
         return self.roomsModel
-    
+
     def get_talks_model(self, event, room, date=None):
         """
         Gets the Talks Model. A talk is defined as "<presenter> - <talk_title>"
         Useful for Qt GUI based Frontends to load the Model into Views.
         """
-        
+
         self.talksModel = QtSql.QSqlQueryModel()
         if date == "":
             self.talksModel.setQuery("SELECT (Speaker || ' - ' || Title), Id FROM presentations \
@@ -334,9 +327,9 @@ class QtDBConnector():
         else:
             self.talksModel.setQuery("SELECT (Speaker || ' - ' || Title), Id FROM presentations \
                                    WHERE Event='%s' and Room='%s' and date(Time) LIKE '%s' ORDER BY Time ASC" % (event, room, date))
-            
+
         return self.talksModel
-    
+
     def get_talk_between_time(self, event, room, starttime, endtime):
         """
         Returns the talkID of the first talk found between a starttime, and endtime for a specified event/room.
@@ -351,12 +344,12 @@ class QtDBConnector():
             return query.value(0)
         else:
             return None
-        
-        
+
+
     ##
     ## Import / Export Functions
     ##
-    
+
     def add_talks_from_rss(self, rss):
         """Adds talks from an rss feed."""
         entry = str(rss)
@@ -375,10 +368,10 @@ class QtDBConnector():
                                     presentation["Room"],
                                     presentation["Time"])
                 self.insert_presentation(talk)
-    
+
     def add_talks_from_csv(self, fname):
         """Adds talks from a csv file.
-        
+
         Title and speaker must be present.
         """
         file = open(fname,'r')
@@ -391,32 +384,32 @@ class QtDBConnector():
                 except KeyError:
                     log.error("Missing Key in Row: %s", row)
                     return
-                    
+
                 try:
                     abstract = unicode(row['Abstract'], 'utf-8') # Description
                 except KeyError:
                     abstract = ''
-                
+
                 try:
                     level = unicode(row['Level'], 'utf-8')
                 except KeyError:
                     level = ''
-                
+
                 try:
                     event = unicode(row['Event'], 'utf-8')
                 except KeyError:
                     event = ''
-                
+
                 try:
                     room = unicode(row['Room'], 'utf-8')
                 except KeyError:
                     room = ''
-                
+
                 try:
                     time = unicode(row['Time'], 'utf-8')
                 except KeyError:
                     time = ''
-                
+
                 talk = Presentation(title,
                                     speaker,
                                     abstract,
@@ -425,13 +418,13 @@ class QtDBConnector():
                                     room,
                                     time)
                 self.insert_presentation(talk)
-            
+
         except IOError:
             log.error("CSV: File %s not found", file)
-        
+
         finally:
             file.close()
-                 
+
     def export_talks_to_csv(self, fname):
         fieldNames = ('Title',
                       'Speaker',
@@ -440,13 +433,13 @@ class QtDBConnector():
                       'Event',
                       'Room',
                       'Time')
-        
+
         try:
             file = open(fname, 'w')
             writer = csv.DictWriter(file, fieldnames=fieldNames)
             headers = dict( (n,n) for n in fieldNames )
             writer.writerow(headers)
-            
+
             result = self.get_talks()
             while result.next():
                 log.debug(unicode(result.value(1).toString()))
@@ -456,10 +449,10 @@ class QtDBConnector():
                                  'Level':    unicode(result.value(4).toString()).encode('utf-8'),
                                  'Event':    unicode(result.value(5).toString()).encode('utf-8'),
                                  'Room':     unicode(result.value(6).toString()).encode('utf-8'),
-                                 'Time':     unicode(result.value(7).toString()).encode('utf-8')})   
+                                 'Time':     unicode(result.value(7).toString()).encode('utf-8')})
         finally:
             file.close()
-    
+
     def export_reports_to_csv(self, fname):
         fieldNames = ('Title',
                       'Speaker',
@@ -475,7 +468,7 @@ class QtDBConnector():
             writer = csv.DictWriter(file, fieldnames=fieldNames)
             headers = dict( (n,n) for n in fieldNames)
             writer.writerow(headers)
-            
+
             result = self.get_reports()
             for report in result:
                 writer.writerow({'Title':    report.presentation.title.encode('utf-8'),
@@ -489,14 +482,14 @@ class QtDBConnector():
                                  'Error':    report.failure.comment.encode('utf-8')})
         finally:
             file.close()
-            
+
     #
     # Reporting Feature
     #
-    
+
     def __create_failures_table(self):
         """
-        Create the failures table in the database 
+        Create the failures table in the database
         Should be used to initialize a new table.
         """
         query = QtSql.QSqlQuery('''CREATE TABLE IF NOT EXISTS failures
@@ -510,11 +503,11 @@ class QtDBConnector():
         Drops the failures (reports) table from the database
         """
         query = QtSql.QSqlQuery('''DROP TABLE IF EXISTS failures''')
-        
+
     def get_report(self, talkid):
         """
         Return a failure from a given talkid
-        
+
         Returned value is a Failure object
         """
         result = QtSql.QSqlQuery('''SELECT * FROM failures WHERE Id = "%s"''' % talkid)
@@ -526,7 +519,7 @@ class QtDBConnector():
         else:
             failure = None
         return failure
-        
+
     def get_reports(self):
         """
         Return a list of failures in Report format.
@@ -543,35 +536,35 @@ class QtDBConnector():
             r = Report(p, failure)
             list.append(r)
         return list
-    
+
     def insert_failure(self, failure):
         """
         Insert a failure into the database.
         """
-        
+
         query = QtSql.QSqlQuery('''INSERT INTO failures VALUES ("%d", "%s", "%s", %d)''' %
                            (int(failure.talkId), failure.comment, failure.indicator, failure.release))
         log.info("Failure added: %s - %s" % (failure.talkId, failure.comment))
-    
+
     def update_failure(self, talk_id, failure):
         """
         Update an existing Failure in the database.
         """
-        
+
         query = QtSqlQuery('''UPDATE failures SET Comments="%s", Indicator="%s", Release="%d" WHERE Id="%s"''' %
                            (failure.comment,
                             failure.indicator,
                             failure.release,
                             failure.talkId))
         log.info("Failure updated: %s %s" % (failure.talkId, failure.comment))
-    
+
     def delete_failure(self, talk_id):
         """
         Removes a Presentation from the database
         """
         query = QtSql.QSqlQuery('''DELETE FROM failures WHERE Id="%s"''' % talk_id)
         log.info("Failure %s deleted." % talk_id)
-        
+
     def get_failures_model(self):
         """
         Gets the Failure reports table Model
@@ -582,16 +575,16 @@ class QtDBConnector():
             self.failuresModel.setTable("failures")
             self.failuresModel.setEditStrategy(QtSql.QSqlTableModel.OnFieldChange)
             self.failuresModel.select()
-        
+
         return self.failuresModel
-        
+
     ##
     ## Controller Feature
     ##
-    
+
     def __create_recentconn_table(self):
         """
-        Create the recentconn table in the database 
+        Create the recentconn table in the database
         Should be used to initialize a new table.
         """
         query = QtSql.QSqlQuery('''CREATE TABLE IF NOT EXISTS recentconn
@@ -599,22 +592,22 @@ class QtDBConnector():
                                          port int,
                                          passphrase varchar(255),
                                          UNIQUE (host, port) ON CONFLICT REPLACE)''')
-                                     
+
     def clear_recentconn_table(self):
         """
         Drops the recentconn (Controller) table from the database
         """
         query = QtSql.QSqlQuery('''DROP TABLE IF EXISTS recentconn''')
-        
+
     def insert_recentconn(self, chost, cport, cpass):
         """
         Insert a failure into the database.
         """
-        
+
         query = QtSql.QSqlQuery('''INSERT INTO recentconn VALUES("%s", "%d", "%s")''' %
                                    (chost, cport, cpass))
         log.info("Recent connection added: %s:%d" % (chost, cport))
-        
+
     def get_recentconn_model(self):
         """
         Gets the Recent Connections table Model
@@ -624,5 +617,5 @@ class QtDBConnector():
         self.recentconnModel.setTable("recentconn")
         self.recentconnModel.setEditStrategy(QtSql.QSqlTableModel.OnFieldChange)
         self.recentconnModel.select()
-        
+
         return self.recentconnModel
